# CommentResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**comment_reference_number** | **str** |  | [optional] 
**comment_topic** | [**CommentTopicResponse**](CommentTopicResponse.md) |  | 
**comment_topic_string** | **str** |  | 
**detail** | **str** |  | 
**author_email_address** | **str** |  | 
**date_created** | **datetime** |  | 
**is_read** | **bool** |  | [optional] 
**read_by** | **str** |  | [optional] 
**read_on** | **datetime** |  | [optional] 
**is_internal** | **bool** |  | [optional] 
**author_organisation_ref** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

